==> dl.php?src=linea21_1_4.zip: linea21/newsletter/quickbox.php <==
<?php
/**
 * @package linea21.modules
 * @subpackage newsletter
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!function_exists('AuthenthificationProcess')) {
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

//////////// Check Droits utilisateur ////////////
if (!HaveRight('news')) ReloadIndex('admin');
////////////

$qbx_module=_t('menu','news');

if ($todo == 'add') {
  $result=$sql_object->DBSelect($req_quickbox_add);
  $qbx_liste='';
  $nb='';
  if($result==0) {
    $qbx_liste.="<li>"._t('divers','nodata')."</li>";
  } else {
    if(count($result)>=10) $nb=10; else $nb=count($result);
    for($i=0; $i<count($result); $i++) {
      $qbx_newsletter_title=formatText(cutText($result[$i]['newsletter_title'], 47), '2HTML');
      $qbx_liste.="<li><a href=\"index.php?id=". $result[$i]['newsletter_id'] ."&amp;rub=".$rub."&amp;todo=det\" title=\""._t('divers','date_crea').": ".$result[$i]['newsletter_date_crea_display']." \">". $qbx_newsletter_title ."</a></li>\n";
    }
  }
  $qbx_h1=$nb._t('newsletter','qb_titleadd');
}

if ($todo == 'mod' || $todo == 'det') {
  $result=$sql_object->DBSelect($req_quickbox_mod);
  $qbx_liste='';
  $nb='';
  if($result==0) {
    $qbx_liste.="<li>"._t('divers','nodata')."</li>";
  } else {
    if(count($result)>=10) $nb=10; else $nb=count($result);
    for($i=0; $i<count($result); $i++) {
      $qbx_newsletter_title=formatText(cutText($result[$i]['newsletter_title'], 47), '2HTML');
      $qbx_liste.="<li><a href=\"index.php?id=". $result[$i]['newsletter_id'] ."&amp;rub=".$rub."&amp;todo=det\" title=\""._t('divers','last_modify')." ".$result[$i]['newsletter_last_modify_display']." - ("._t('divers','date_crea').": ".$result[$i]['newsletter_date_crea_display'].") \">". $qbx_newsletter_title ."</a></li>\n";
    }
  }
  $qbx_h1=$nb._t('newsletter','qb_titlemod');
}
if ($todo == 'sup') {
  $result=$sql_object->DBSelect($req_quickbox_sup);
  $qbx_liste='';
  $nb='';
  if($result==0) {
    $qbx_liste.="<li>"._t('divers','nodata')."</li>";
  } else {
    if(count($result)>=10) $nb=10; else $nb=count($result);
    for($i=0; $i<count($result); $i++) {
      $qbx_newsletter_title=formatText(cutText($result[$i]['newsletter_title'], 47), '2HTML');
      $qbx_liste.="<li><a href=\"#\" title=\""._t('divers','date_sup')." ".$result[$i]['newsletter_last_modify_display']." - ("._t('divers','date_crea').": ".$result[$i]['newsletter_date_crea_display'].") \">". $qbx_newsletter_title ."</a></li>\n";
    }
  }
  $qbx_h1=$nb._t('newsletter','qb_titlesup');
}
if ($todo == 'list') {
  $result=$sql_object->DBSelect($req_quickbox_list);
  $qbx_liste='';
  $nb='';
  if($result==0) {
    $qbx_liste.="<li>"._t('divers','nodata')."</li>";
  } else {
    if(count($result)>=10) $nb=10; else $nb=count($result);
    for($i=0; $i<count($result); $i++) {
      $qbx_newsletter_title=formatText(cutText($result[$i]['newsletter_title'], 47), '2HTML');
      $qbx_liste.="<li><a href=\"index.php?id=". $result[$i]['newsletter_id'] ."&amp;rub=".$rub."&amp;todo=det\" title=\""._t('divers','date_publi')." ".$result[$i]['newsletter_published_date_display']." - ("._t('divers','date_crea').": ".$result[$i]['newsletter_date_crea_display'].") \">". $qbx_newsletter_title ."</a></li>\n";
    }
  }
  $qbx_h1=$nb._t('newsletter','qb_titlepubli');
}

echo QuickBoxNow($qbx_module, $qbx_h1, $qbx_liste);
echo "</div>\n";
?>

==> dl.php?src=linea21_1_7.zip: linea21/newsletter/quickbox.php <==
<?php
/**
 * @package linea21.modules
 * @subpackage newsletter
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')) {
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

//////////// Check Droits utilisateur ////////////
if (!$l21auth->hasRight('news')) ReloadIndex('admin');
////////////

$qbx_module=_t('menu','news');

if ($todo == 'add') {
  $result=$sql_object->DBSelect($req_quickbox_add);
  $qbx_liste='';
  $nb='';
  if($result==0) {
    $qbx_liste.="<li>"._t('divers','nodata')."</li>";
  } else {
    if(count($result)>=10) $nb=10; else $nb=count($result);
    for($i=0; $i<count($result); $i++) {
      $qbx_newsletter_title=formatText(cutText($result[$i]['newsletter_title'], 47), '2HTML');
      $qbx_liste.="<li><a href=\"index.php?id=". $result[$i]['newsletter_id'] ."&amp;rub=".$rub."&amp;todo=det\" title=\""._t('divers','date_crea').": ".$result[$i]['newsletter_date_crea_display']." \">". $qbx_newsletter_title ."</a></li>\n";
    }
  }
  $qbx_h1=$nb._t('newsletter','qb_titleadd');
}

if ($todo == 'mod' || $todo == 'det') {
  $result=$sql_object->DBSelect($req_quickbox_mod);
  $qbx_liste='';
  $nb='';
  if($result==0) {
    $qbx_liste.="<li>"._t('divers','nodata')."</li>";
  } else {
    if(count($result)>=10) $nb=10; else $nb=count($result);
    for($i=0; $i<count($result); $i++) {
      $qbx_newsletter_title=formatText(cutText($result[$i]['newsletter_title'], 47), '2HTML');
      $qbx_liste.="<li><a href=\"index.php?id=". $result[$i]['newsletter_id'] ."&amp;rub=".$rub."&amp;todo=det\" title=\""._t('divers','last_modify')." ".$result[$i]['newsletter_last_modify_display']." - ("._t('divers','date_crea').": ".$result[$i]['newsletter_date_crea_display'].") \">". $qbx_newsletter_title ."</a></li>\n";
    }
  }
  $qbx_h1=$nb._t('newsletter','qb_titlemod');
}
if ($todo == 'sup') {
  $result=$sql_object->DBSelect($req_quickbox_sup);
  $qbx_liste='';
  $nb='';
  if($result==0) {
    $qbx_liste.="<li>"._t('divers','nodata')."</li>";
  } else {
    if(count($result)>=10) $nb=10; else $nb=count($result);
    for($i=0; $i<count($result); $i++) {
      $qbx_newsletter_title=formatText(cutText($result[$i]['newsletter_title'], 47), '2HTML');
      $qbx_liste.="<li><a href=\"#\" title=\""._t('divers','date_sup')." ".$result[$i]['newsletter_last_modify_display']." - ("._t('divers','date_crea').": ".$result[$i]['newsletter_date_crea_display'].") \">". $qbx_newsletter_title ."</a></li>\n";
    }
  }
  $qbx_h1=$nb._t('newsletter','qb_titlesup');
}
if ($todo == 'list') {
  $result=$sql_object->DBSelect($req_quickbox_list);
  $qbx_liste='';
  $nb='';
  if($result==0) {
    $qbx_liste.="<li>"._t('divers','nodata')."</li>";
  } else {
    if(count($result)>=10) $nb=10; else $nb=count($result);
    for($i=0; $i<count($result); $i++) {
      $qbx_newsletter_title=formatText(cutText($result[$i]['newsletter_title'], 47), '2HTML');
      $qbx_liste.="<li><a href=\"index.php?id=". $result[$i]['newsletter_id'] ."&amp;rub=".$rub."&amp;todo=det\" title=\""._t('divers','date_publi')." ".$result[$i]['newsletter_published_date_display']." - ("._t('divers','date_crea').": ".$result[$i]['newsletter_date_crea_display'].") \">". $qbx_newsletter_title ."</a></li>\n";
    }
  }
  $qbx_h1=$nb._t('newsletter','qb_titlepubli');
}

echo QuickBoxNow($qbx_module, $qbx_h1, $qbx_liste);
echo "</div>\n";
?>
